Learn R Programming

rrnni (version 0.1.1)

validate_rankedPhylo: Validate rankedPhylo class

Description

Validate that the object is a rankedPhylo object with a proper structure and type.

Usage

validate_rankedPhylo(x)

Value

This function doesn't have a return value.

Arguments

x

an object of class "rankedPhylo"

Details

This is internal function used for testing purposes.

"rankedPhylo" is a subclass of "phylo" object with several restrictions given by the structure of the represented ranked tree. validate_rankedPhylo checks these restrictions and throw a particular error, if the object fails any of these restrictions.