powered by
Read a tree in a newick format and convert it to a rankedPhylo
read_newick(x)
object of class "rankedPhylo"
a single character string containing tree in a newick format
read_newick("((A:1,B:1):1,C:2);") # Note, not all valid newick trees are valid ranked trees try( read_newick("((A,B),C);") )
Run the code above in your browser using DataLab